@@ -60,7 +60,7 @@ class FediGroupBot:
     def __update_group_members(self):
         self.group_members, max_id, last_max_id = [], None, None
         followers = self.masto.account_followers(self.id, limit=sys.maxsize, max_id=max_id)  # NOQA: E501
-        while len(followers) > 1:
+        while len(followers):
             self.group_members += [member.acct for member in followers]
             max_id = followers[-1].id
             if last_max_id == max_id:
@@ -70,9 +70,9 @@ class FediGroupBot:
 
         self.group_admins, max_id, last_max_id = [], None, None
         following = self.masto.account_following(self.id, limit=sys.maxsize, max_id=max_id)  # NOQA: E501
-        while len(following) > 1:
+        while len(following):
             self.group_admins += [member.acct for member in following]
-            max_id = followers[-1].id
+            max_id = following[-1].id
             if last_max_id == max_id:
                 break
             last_max_id = max_id
